@@ -1,5 +1,5 @@
 package T45_Base;
-use Object::Simple;
+use Object::Simple(base => 'T45_Base_Base');
 
 sub m1 {
     my $self = shift;
@@ -19,5 +19,10 @@ sub m5 {
     return $val + 5;
 }
 
+sub m6 {
+    my $self = shift;
+    $self->Object::Simple::call_super('m6', @_) * 3;
+}
+
 
 Object::Simple->build_class;
